"use strict";
Object.defineProperty(exports, "createMainSlice", {
    enumerable: true,
    get: ()=>createMainSlice
});
const _extends = require("@swc/helpers/lib/_extends.js").default;
const _toolkit = require("@reduxjs/toolkit");
const _lodash = require("lodash");
const _uuid = require("uuid");
const createMainSlice = ()=>{
    const initialState = {
        root: [],
        path: [],
        nodes: {}
    };
    return (0, _toolkit.createSlice)({
        name: 'main',
        initialState,
        reducers: {
            insertItem: (state, action)=>{
                const id = (0, _uuid.v4)();
                const { item , parentId  } = action.payload;
                state.nodes[id] = {
                    id,
                    parentId,
                    children: [],
                    original: _extends({}, item, {
                        id
                    })
                };
                if (parentId) {
                    state.nodes[parentId].children.push(id);
                }
                state.root = (0, _lodash.values)(state.nodes).filter((i)=>i && !i.parentId).map((i)=>i.id);
            },
            push: (state, action)=>{
                const { section , itemId  } = action.payload;
                const currentPath = state.path;
                if (section !== undefined && currentPath[section]) {
                    currentPath.splice(section, 1, itemId);
                    currentPath.splice(section + 1, currentPath.length - section);
                } else {
                    currentPath.push(itemId);
                }
                state.path = currentPath;
            },
            select: (state, action)=>{
                const { itemId  } = action.payload;
                const item = state.nodes[itemId];
                const newPath = [
                    item.id
                ];
                if (item.parentId) {
                    let parentId = item.parentId;
                    while(parentId !== ''){
                        const node = state.nodes[parentId];
                        newPath.push(node.id);
                        parentId = node.parentId || '';
                    }
                }
                state.path = newPath.reverse();
            }
        }
    });
};

//# sourceMappingURL=index.js.map